@@ -21,13 +21,13 @@
 
 int main(int argc, char *argv[])
 {
-  Glib::RefPtr<ExampleApplication> application = 
+  auto application =
     ExampleApplication::create();
 
-  // Start the application, showing the initial window, 
+  // Start the application, showing the initial window,
   // and opening extra windows for any files that it is asked to open,
   // for instance as a command-line parameter.
   // run() will return when the last window has been closed by the user.
-  const int status = application->run(argc, argv);
+  const auto status = application->run(argc, argv);
   return status;
 }
