@@ -17,24 +17,26 @@
 #include "examplewindow.h"
 
 ExampleWindow::ExampleWindow()
-: m_AspectFrame("2x1", /* label */
+: m_AspectFrame(
     Gtk::Align::CENTER, /* center x */
     Gtk::Align::CENTER, /* center y */
     2.0, /* xsize/ysize = 2 */
-    false /* ignore child's aspect */)
+    false /* ignore child's aspect */),
+  m_Frame("2x1" /* label */)
 {
   set_title("Aspect Frame");
 
-  // Add a child widget to the aspect frame */
+  // Set a child widget to the aspect frame */
   // Ask for a 200x200 window, but the AspectFrame will give us a 200x100
   // window since we are forcing a 2x1 aspect ratio */
   m_DrawingArea.set_content_width(200);
   m_DrawingArea.set_content_height(200);
-  m_AspectFrame.add(m_DrawingArea);
+  m_Frame.set_child(m_DrawingArea);
+  m_AspectFrame.set_child(m_Frame);
   m_AspectFrame.set_margin(10);
 
   // Add the aspect frame to our toplevel window:
-  add(m_AspectFrame);
+  set_child(m_AspectFrame);
 }
 
 ExampleWindow::~ExampleWindow()
