@@ -1,5 +1,3 @@
-//$Id: clock.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,18 +24,15 @@ Clock::Clock()
 : m_radius(0.42), m_line_width(0.05)
 {
   Glib::signal_timeout().connect( sigc::mem_fun(*this, &Clock::on_timeout), 1000 );
+  set_draw_func(sigc::mem_fun(*this, &Clock::on_draw));
 }
 
 Clock::~Clock()
 {
 }
 
-bool Clock::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
+void Clock::on_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height)
 {
-  Gtk::Allocation allocation = get_allocation();
-  const int width = allocation.get_width();
-  const int height = allocation.get_height();
-
   // scale to unit square and translate (0, 0) to be (0.5, 0.5), i.e.
   // the center of the window
   cr->scale(width, height);
@@ -62,7 +57,7 @@ bool Clock::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
     double inset = 0.05;
 
     cr->save();
-    cr->set_line_cap(Cairo::LINE_CAP_ROUND);
+    cr->set_line_cap(Cairo::Context::LineCap::ROUND);
 
     if(i % 3 != 0)
     {
@@ -91,7 +86,7 @@ bool Clock::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
   double seconds= timeinfo->tm_sec * M_PI / 30;
 
   cr->save();
-  cr->set_line_cap(Cairo::LINE_CAP_ROUND);
+  cr->set_line_cap(Cairo::Context::LineCap::ROUND);
 
   // draw the seconds hand
   cr->save();
@@ -121,20 +116,11 @@ bool Clock::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
   // draw a little dot in the middle
   cr->arc(0, 0, m_line_width / 3.0, 0, 2 * M_PI);
   cr->fill();
-
-  return true;
 }
 
-
 bool Clock::on_timeout()
 {
-    // force our program to redraw the entire clock.
-    auto win = get_window();
-    if (win)
-    {
-        Gdk::Rectangle r(0, 0, get_allocation().get_width(),
-                get_allocation().get_height());
-        win->invalidate_rect(r, false);
-    }
-    return true;
+  // force our program to redraw the entire clock.
+  queue_draw();
+  return true;
 }
