@@ -27,8 +27,7 @@ public:
   virtual ~MyArea();
 
 protected:
-  //Override default signal handler:
-  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
+  void on_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height);
 
   Glib::RefPtr<Gdk::Pixbuf> m_image;
 };
