@@ -26,8 +26,7 @@ public:
   virtual ~MyArea();
 
 protected:
-  //Override default signal handler:
-  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
+  void on_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height);
 
 private:
   void draw_rectangle(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height);
