@@ -19,19 +19,17 @@
 MyArea::MyArea()
 : m_fix (0)
 {
-  set_size_request (200, 100);
+  set_content_width(200);
+  set_content_height(100);
+  set_draw_func(sigc::mem_fun(*this, &MyArea::on_draw));
 }
 
 MyArea::~MyArea()
 {
 }
 
-bool MyArea::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
+void MyArea::on_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height)
 {
-  Gtk::Allocation allocation = get_allocation();
-  const int width = allocation.get_width();
-  const int height = allocation.get_height();
-
   cr->set_line_width(1.0);
 
   // draw one line, every two pixels
@@ -44,8 +42,6 @@ bool MyArea::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
   }
 
   cr->stroke();
-
-  return true;
 }
 
 // Toogle between both values (0 or 0.5)
@@ -54,16 +50,6 @@ void MyArea::fix_lines(bool fix)
   // to get the width right, we have to draw in the middle of the pixel
   m_fix = fix ? 0.5 : 0.0;
 
-  force_redraw();
-}
-
-// force the redraw of the image
-void MyArea::force_redraw()
-{
-  auto win = get_window();
-  if (win)
-  {
-    Gdk::Rectangle r(0, 0, get_allocation().get_width(), get_allocation().get_height());
-    win->invalidate_rect(r, false);
-  }
+  // force the redraw of the image
+  queue_draw();
 }
