@@ -26,11 +26,9 @@ public:
   virtual ~MyArea();
 
   void fix_lines(bool fix = true);
-  void force_redraw();
 
 protected:
-  //Override default signal handler:
-  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
+  void on_draw(const Cairo::RefPtr<Cairo::Context>& cr, int width, int height);
 
 private:
   double m_fix;
