@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,7 +27,7 @@ public:
 
 protected:
   //Signal handlers:
-  void on_icon_pressed(Gtk::EntryIconPosition icon_pos, const GdkEventButton* event);
+  void on_icon_pressed(Gtk::Entry::IconPosition icon_pos);
   void on_button_close();
 
   //Child widgets:
