@@ -19,10 +19,12 @@
 
 #include <gtkmm.h>
 
+#include <memory>
+
 class ExampleWindow : public Gtk::Window
 {
 public:
-  ExampleWindow();
+  ExampleWindow(const Glib::RefPtr<Gtk::Application>& app);
   virtual ~ExampleWindow();
 
 protected:
@@ -34,11 +36,10 @@ protected:
   //Child widgets:
   Gtk::Box m_Box;
   Gtk::Label m_Label;
+  Gtk::PopoverMenu m_MenuPopup;
 
   Glib::RefPtr<Gtk::Builder> m_refBuilder;
-  Glib::RefPtr<Gtk::GestureMultiPress> m_refGesture;
-
-  Gtk::Menu* m_pMenuPopup;
+  Glib::RefPtr<Gtk::GestureClick> m_refGesture;
 };
 
 #endif //GTKMM_EXAMPLEWINDOW_H
