@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 654 2006-06-14 01:00:12Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2006 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +20,6 @@
 #include <gtkmm/box.h>
 #include <gtkmm/window.h>
 #include <gtkmm/button.h>
-#include <gtkmm/buttonbox.h>
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/listviewtext.h>
 
@@ -42,7 +39,7 @@ protected:
   Gtk::ScrolledWindow m_ScrolledWindow;
   Gtk::ListViewText m_ListViewText;
 
-  Gtk::ButtonBox m_ButtonBox;
+  Gtk::Box m_ButtonBox;
   Gtk::Button m_Button_Quit;
 };
 
